@@ -146,10 +146,6 @@ pub(crate) fn get_full_command(
 /// quickly as possible.
 fn main() -> ! {
     let argv: Vec<OsString> = std::env::args_os().collect();
-    unsafe {
-        // SAFETY: It's sound as we don't manipulate environment variables while querying local offsets.
-        time::util::local_offset::set_soundness(time::util::local_offset::Soundness::Unsound);
-    }
 
     // Chicken and egg: the --color option must be parsed from argv in order to setup
     // clap with the desired color choice. So a simple pre-parse is performed just to
@@ -383,7 +379,7 @@ fn execute_shell_alias(
         if user_args.is_empty() {
             command.arg(&alias.command);
         } else {
-            command.arg(&format!("{} \"$@\"", &alias.command));
+            command.arg(format!("{} \"$@\"", &alias.command));
             command.arg(&alias.command);
         }
         command
