@@ -213,12 +213,10 @@ impl<'repo> ExecuteContext<'repo> {
             } else {
                 reflog_msg
             };
-            let stack_ref = repo.find_reference(stack.get_stack_refname())?;
             let branch_ref_name = stack.get_branch_refname().to_owned();
-            let prev_state_commit = stack_ref
-                .into_fully_peeled_id()?
-                .object()?
-                .try_into_commit()?;
+            let prev_state_commit = repo
+                .find_reference(stack.get_stack_refname())?
+                .peel_to_commit()?;
             let state = stack.state_mut();
             for (patchname, maybe_patch) in &updated_patches {
                 if let Some(patch) = maybe_patch {
@@ -248,7 +246,7 @@ impl<'repo> ExecuteContext<'repo> {
                     gix::refs::transaction::Change::Update {
                         log: log.clone(),
                         expected: gix::refs::transaction::PreviousValue::Any, // TODO?
-                        new: gix::refs::Target::Peeled(patch.commit.id),
+                        new: gix::refs::Target::Object(patch.commit.id),
                     }
                 } else {
                     gix::refs::transaction::Change::Delete {
@@ -269,12 +267,12 @@ impl<'repo> ExecuteContext<'repo> {
                     log: log.clone(),
                     expected: if let Some(prev_state_commit) = stack.state_mut().prev.as_ref() {
                         gix::refs::transaction::PreviousValue::ExistingMustMatch(
-                            gix::refs::Target::Peeled(prev_state_commit.id),
+                            gix::refs::Target::Object(prev_state_commit.id),
                         )
                     } else {
                         gix::refs::transaction::PreviousValue::MustNotExist
                     },
-                    new: gix::refs::Target::Peeled(state_commit_id),
+                    new: gix::refs::Target::Object(state_commit_id),
                 },
                 name: gix::refs::FullName::try_from(stack.get_stack_refname())
                     .expect("stack reference name is valid"),
@@ -286,7 +284,7 @@ impl<'repo> ExecuteContext<'repo> {
                     change: gix::refs::transaction::Change::Update {
                         log,
                         expected: gix::refs::transaction::PreviousValue::Any,
-                        new: gix::refs::Target::Peeled(trans_head.id),
+                        new: gix::refs::Target::Object(trans_head.id),
                     },
                     name: branch_ref_name.clone(),
                     deref: false,
